==> flink-1.11.6-src.tgz: flink-1.11.6/docs/dev/python/table-api-users-guide/index.md <==
---
title: "Table API User's Guide"
nav-id: python_tableapi
nav-parent_id: python
nav-pos: 25
---
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

Python Table API allows users to develop [Table API]({% link dev/table/tableApi.md %}) programs using the Python language.
Apache Flink has provided Python Table API support since 1.9.0.

## Where to go next?

- [Installation]({% link dev/python/installation.md %}): Introduction of how to set up the Python Table API execution environment.
- [Python Data Types]({% link dev/python/table-api-users-guide/python_types.md %}): Introduction of Python data types.
- [User-defined Functions]({% link dev/python/table-api-users-guide/udfs/python_udfs.md %}): Explanation of how to define Python user-defined functions.
- [Vectorized User-defined Functions]({% link dev/python/table-api-users-guide/udfs/vectorized_python_udfs.md %}): Explanation of how to define vectorized Python user-defined functions.
- [Conversions between PyFlink Table and Pandas DataFrame]({% link dev/python/table-api-users-guide/conversion_of_pandas.md %}): Explanation of how to convert between PyFlink Table and Pandas DataFrame.
- [Dependency Management]({% link dev/python/table-api-users-guide/dependency_management.md %}): Specification of how to use third-part dependencies in a Python Table API program.
- [Configuration]({% link dev/python/table-api-users-guide/python_config.md %}): Description of the config options available for Python Table API programs.
- [Common Questions]({% link dev/python/faq.md %})

==> flink-1.12.7-src.tgz: flink-1.12.7/docs/dev/python/table-api-users-guide/index.md <==
---
title: "Table API User's Guide"
nav-id: python_tableapi
nav-parent_id: python
nav-pos: 25
---
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

The Python Table API allows users to develop [Table API]({% link dev/table/tableApi.md %}) programs using the Python language.

## Where to go next?

- [Installation]({% link dev/python/installation.md %}): Introduction of how to set up the Python Table API execution environment.
- [Python Data Types]({% link dev/python/table-api-users-guide/python_types.md %}): Introduction of Python data types.
- [User-defined Functions]({% link dev/python/table-api-users-guide/udfs/python_udfs.md %}): Explanation of how to define Python user-defined functions.
- [Vectorized User-defined Functions]({% link dev/python/table-api-users-guide/udfs/vectorized_python_udfs.md %}): Explanation of how to define vectorized Python user-defined functions.
- [Conversions between PyFlink Table and Pandas DataFrame]({% link dev/python/table-api-users-guide/conversion_of_pandas.md %}): Explanation of how to convert between PyFlink Table and Pandas DataFrame.
- [Common Questions]({% link dev/python/faq.md %})
